@@ -39,7 +39,7 @@ class BaseClient:
                     self.store.store(session=session_id, user=login.get_value('user'))
                     break
                 except Exception as e:
-                    print e
+                    print("Error writing token: {}".format(e))
             else:
                 session = SoapSession(session_id=session_id, instance=instance)
                 if not session.is_valid():
