@@ -24,10 +24,10 @@ class Chatter(BaseClient):
             
         for item in feed['items']:
             header = "========================================================="
-            print "\n{}\n{}:\n{}".format(header, item['preamble']['text'], header)
+            print("\n{}\n{}:\n{}".format(header, item['preamble']['text'], header))
             for segment in item['body']['messageSegments']:
                 if  segment['type'] == 'Text':
-                    print "{}".format(segment['text'].replace('\n',' '))
+                    print("{}".format(segment['text'].replace('\n',' ')))
     
     def post_chatter_message(self, messageText, obj=None):
         if obj is None:
